@@ -1,6 +1,6 @@
 /* md5wrap.h: wrapper functions to allow easy use of MD5 from C++.
  *
- * Copyright (C) 2006,2007,2010 Olly Betts
+ * Copyright (C) 2006,2007,2010,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #include <string>
 
 bool md5_file(const std::string &file_name, std::string &md5, bool try_noatime);
-void md5_string(const std::string &str, std::string &md5);
+void md5_block(const char * p, size_t len, std::string &md5);
+inline void md5_string(const std::string &str, std::string &md5) {
+    md5_block(str.data(), str.size(), md5);
+}
 
 #endif // OMEGA_INCLUDED_MD5WRAP_H
